==> cxf-testutils-2.0.3.4-fuse-sources.jar: org/apache/type_test/doc/TestStructWithMultipleSubstitutionGroups.java <==

package org.apache.type_test.doc;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.type_test.types3.StructWithMultipleSubstitutionGroups;


/**
 * <p>Java class for testStructWithMultipleSubstitutionGroups element declaration.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;element name="testStructWithMultipleSubstitutionGroups">
 *   &lt;complexType>
 *     &lt;complexContent>
 *       &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *         &lt;sequence>
 *           &lt;element name="x" type="{http://apache.org/type_test/types3}StructWithMultipleSubstitutionGroups"/>
 *           &lt;element name="y" type="{http://apache.org/type_test/types3}StructWithMultipleSubstitutionGroups"/>
 *         &lt;/sequence>
 *       &lt;/restriction>
 *     &lt;/complexContent>
 *   &lt;/complexType>
 * &lt;/element>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "x",
    "y"
})
@XmlRootElement(name = "testStructWithMultipleSubstitutionGroups")
public class TestStructWithMultipleSubstitutionGroups {

    @XmlElement(namespace = "http://apache.org/type_test/doc", required = true)
    protected StructWithMultipleSubstitutionGroups x;
    @XmlElement(namespace = "http://apache.org/type_test/doc", required = true)
    protected StructWithMultipleSubstitutionGroups y;

    /**
     * Gets the value of the x property.
     * 
     * @return
     *     possible object is
     *     {@link StructWithMultipleSubstitutionGroups }
     *     
     */
    public StructWithMultipleSubstitutionGroups getX() {
        return x;
    }

    /**
     * Sets the value of the x property.
     * 
     * @param value
     *     allowed object is
     *     {@link StructWithMultipleSubstitutionGroups }
     *     
     */
    public void setX(StructWithMultipleSubstitutionGroups value) {
        this.x = value;
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     {@link StructWithMultipleSubstitutionGroups }
     *     
     */
    public StructWithMultipleSubstitutionGroups getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     {@link StructWithMultipleSubstitutionGroups }
     *     
     */
    public void setY(StructWithMultipleSubstitutionGroups value) {
        this.y = value;
    }

}

==> cxf-testutils-2.1.3.20-fuse-sources.jar: org/apache/type_test/doc/TestStructWithMultipleSubstitutionGroups.java <==

package org.apache.type_test.doc;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.type_test.types3.StructWithMultipleSubstitutionGroups;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="x" type="{http://apache.org/type_test/types3}StructWithMultipleSubstitutionGroups"/>
 *         &lt;element name="y" type="{http://apache.org/type_test/types3}StructWithMultipleSubstitutionGroups"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "x",
    "y"
})
@XmlRootElement(name = "testStructWithMultipleSubstitutionGroups")
public class TestStructWithMultipleSubstitutionGroups {

    @XmlElement(required = true)
    protected StructWithMultipleSubstitutionGroups x;
    @XmlElement(required = true)
    protected StructWithMultipleSubstitutionGroups y;

    /**
     * Gets the value of the x property.
     * 
     * @return
     *     possible object is
     *     {@link StructWithMultipleSubstitutionGroups }
     *     
     */
    public StructWithMultipleSubstitutionGroups getX() {
        return x;
    }

    /**
     * Sets the value of the x property.
     * 
     * @param value
     *     allowed object is
     *     {@link StructWithMultipleSubstitutionGroups }
     *     
     */
    public void setX(StructWithMultipleSubstitutionGroups value) {
        this.x = value;
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     {@link StructWithMultipleSubstitutionGroups }
     *     
     */
    public StructWithMultipleSubstitutionGroups getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     {@link StructWithMultipleSubstitutionGroups }
     *     
     */
    public void setY(StructWithMultipleSubstitutionGroups value) {
        this.y = value;
    }

}
